@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0008';
+our $VERSION = '0.0009';
 
 use Moo;
 use strictures 2;
@@ -122,6 +122,28 @@ sub recall_names {
   return $results;
 }
 
+
+sub remove_setting {
+  my ($self, %args) = @_;
+  my $id = delete $args{id};
+  croak 'No id given' unless $id;
+  $self->_sqlite->delete(
+    $self->model,
+    { id => $id }
+  );
+}
+
+
+sub remove_settings {
+  my ($self, %args) = @_;
+  my $name = delete $args{name};
+  croak 'No name given' unless $name;
+  $self->_sqlite->delete(
+    $self->model,
+    { name => $name }
+  );
+}
+
 1;
 
 __END__
@@ -136,7 +158,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0008
+version 0.0009
 
 =head1 SYNOPSIS
 
@@ -161,6 +183,10 @@ version 0.0008
   my $settings = $synth->recall_settings(name => $names->[0]);
   # [ 1 => { etc => '!!!' }, 2 => { etc => '???' } ]
 
+  $synth->remove_setting(id => $id1);
+
+  $synth->remove_settings(name => $name);
+
 =head1 DESCRIPTION
 
 C<Synth::Config> provides a way to save and recall synthesizer control
@@ -242,6 +268,18 @@ Return all the settings for a given B<name>.
 
 Return all the setting names.
 
+=head2 remove_setting
+
+  $synth->remove_setting(id => $id);
+
+Remove a setting given an B<id>.
+
+=head2 remove_settings
+
+  $synth->remove_settings(name => $name);
+
+Remove all settings for a given B<name>.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> file in this distribution
